# Marc E. Fiuczynski <mef@cs.princeton.edu>
# Thierry Parmentelat <thierry.parmentelat@inria.fr>
# Copyright (C) 2006 The Trustees of Princeton University
# License is GPL.

# NOTE.
# This specfile has additions so it can build against a stock-fedora kernel
# (see the section that defines 'percent' below)
# However this is not used, since we use the stock fedora kernel starting with f16
# which provides for the atheros drivers as part of the kernel rpm already
# also, the release of madwifi for which this addition was made (20100921)
# does not seem to build against the stock fedora kernel anyway
# 
#
# kernel_release, kernel_version and kernel_arch are expected to be set by the build to e.g.
# kernel_release : 24.onelab  (24 is then the planetlab taglevel)
# kernel_version : 2.6.27.57 | 2.6.32  (57 in the 27 case is the patch level)
# kernel_arch :    i686 | x86_64

%define name madwifi
%define version 4132
%define taglevel 6

%define actual_name %{name}-trunk-r%{version}-20100921

# when no planetlab kernel is being built, kernel_version is defined but empty
%define _with_planetlab_kernel %{?kernel_version:1}%{!?kernel_version:0}
# we need to make sure that this rpm gets upgraded when the kernel release changes
%if %{_with_planetlab_kernel}
# with the planetlab kernel
%define pl_kernel_taglevel %( echo %{kernel_release} | cut -d. -f1 )
%define madwifi_release %{kernel_version}.%{pl_kernel_taglevel}
%else
# with the stock kernel
# this line below
#%define madwifi_release %( rpm -q --qf "%{version}" kernel-headers )
# causes recursive macro definition no matter how much you quote
%define percent %
%define braop \{
%define bracl \}
%define kernel_version %( rpm -q --qf %{percent}%{braop}version%{bracl} kernel-headers )
%define kernel_release %( rpm -q --qf %{percent}%{braop}release%{bracl} kernel-headers )
%define kernel_arch %( rpm -q --qf %{percent}%{braop}arch%{bracl} kernel-headers )
%define madwifi_release %{kernel_version}.%{kernel_release}
%endif

%define release %{madwifi_release}.%{taglevel}%{?pldistro:.%{pldistro}}%{?date:.%{date}}

# guess which convention is used; k27 and before used dash, k32 uses dot
%define kernelpath_dash /usr/src/kernels/%{kernel_version}-%{kernel_release}-%{kernel_arch}
%define kernelpath_dot /usr/src/kernels/%{kernel_version}-%{kernel_release}.%{kernel_arch}
%define kernelpath %( [ -d %{kernelpath_dot} ] && echo %{kernelpath_dot} || echo %{kernelpath_dash} )

# the k32 kernel currently builds e.g. /lib/modules/2.6.32-0.onelab.2010.12.07-i686
# the k27 and before does not have the -i686 part
%define kernel_id_old %{kernel_version}-%{kernel_release}
%define kernel_id_new %{kernel_version}-%{kernel_release}.%{kernel_arch}
%define kernel_id %( [ -d %{kernelpath_dot} ] && echo %{kernel_id_new} || echo %{kernel_id_old} )

Summary: madwifi Atheros driver
Name: %{name}
Version: %{version}
Release: %{release}
License: GPL
Group: System Environment/Kernel
Source0: %{actual_name}.tar.gz
Source1: ifup-pre-local
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot

Vendor: MadWifi
Packager: PlanetLab <devel@planet-lab.org>
Distribution: PlanetLab %{plrelease}
URL: %{SCMURL}

Requires: kernel = %{kernel_version}-%{kernel_release}
Requires: coreutils

%description
madwifi is a new generation driver for the Atheros chipset

%prep
%setup -n %{actual_name}

%build
rm -rf $RPM_BUILD_ROOT

%__make KERNELPATH=%kernelpath clean
%__make KERNELPATH=%kernelpath

%install
rm -fr $RPM_BUILD_ROOT

echo 'r' | %__make KERNELPATH=%kernelpath BINDIR=/sbin MANDIR=%{_mandir} DESTDIR=$RPM_BUILD_ROOT install
install -D -m 755 %{SOURCE1} $RPM_BUILD_ROOT/sbin/ifup-pre-local

# Remove depmod files, will be regenerated in %post
rm -f $RPM_BUILD_ROOT/lib/modules/%{kernel_id}/modules.*

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%dir /lib/modules/%{kernel_id}
/lib/modules/%{kernel_id}/net/ath_hal.ko
/lib/modules/%{kernel_id}/net/ath_pci.ko
/lib/modules/%{kernel_id}/net/ath_rate_sample.ko
/lib/modules/%{kernel_id}/net/ath_rate_amrr.ko
/lib/modules/%{kernel_id}/net/ath_rate_onoe.ko
/lib/modules/%{kernel_id}/net/wlan.ko
/lib/modules/%{kernel_id}/net/wlan_acl.ko
/lib/modules/%{kernel_id}/net/wlan_ccmp.ko
/lib/modules/%{kernel_id}/net/wlan_scan_ap.ko
/lib/modules/%{kernel_id}/net/wlan_scan_sta.ko
/lib/modules/%{kernel_id}/net/wlan_tkip.ko
/lib/modules/%{kernel_id}/net/wlan_wep.ko
/lib/modules/%{kernel_id}/net/wlan_xauth.ko
/lib/modules/%{kernel_id}/net/ath_rate_minstrel.ko
/sbin/80211debug
/sbin/80211stats
/sbin/athchans
/sbin/athctrl
/sbin/athdebug
/sbin/athkey
/sbin/athstats
/sbin/wlanconfig
/sbin/ath_info
/sbin/ifup-pre-local
/sbin/madwifi-unload
/sbin/wpakey
%{_mandir}/man8/80211debug.8*
%{_mandir}/man8/80211stats.8*
%{_mandir}/man8/athchans.8*
%{_mandir}/man8/athctrl.8*
%{_mandir}/man8/athdebug.8*
%{_mandir}/man8/athkey.8*
%{_mandir}/man8/athstats.8*
%{_mandir}/man8/wlanconfig.8*
%{_mandir}/man8/ath_info.8*


%post
depmod -a %{kernel_id} >/dev/null 2>&1 || :

# ask for a reboot

%preun

%postun
# 0 = erase, 1 = upgrade
if [ $1 -eq 0 ] ; then
    dir=/lib/modules/%{kernel_id}
    # If we were the only module installed, remove the module dependencies
    if [ ! -d $dir/kernel ] ; then
	[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rmmoddep --remove %{kernel_id}
    else
	depmod -a %{kernel_id} >/dev/null 2>&1 || :
    fi
fi

%changelog
* Tue Sep 04 2012 Thierry Parmentelat <thierry.parmentelat@sophia.inria.fr> - madwifi-4132-6
- can build against a stock fedora kernel
- turned out useless as fedora16 has these drivers natively

* Mon Jan 30 2012 Thierry Parmentelat <thierry.parmentelat@sophia.inria.fr> - madwifi-4132-5
- search third-party in dual location

* Mon Oct 24 2011 Thierry Parmentelat <thierry.parmentelat@sophia.inria.fr> - madwifi-4132-4
- for building against k32 on f8

* Sun Oct 02 2011 Thierry Parmentelat <thierry.parmentelat@sophia.inria.fr> - madwifi-4132-3
- rpm version number has the kernel taglevel embedded

* Sun Jan 23 2011 Thierry Parmentelat <thierry.parmentelat@sophia.inria.fr> - madwifi-4132-2
- build tweaked for k32

* Thu Oct 02 2008 Thierry Parmentelat <thierry.parmentelat@sophia.inria.fr> - madwifi-0.9.4-2
- specfile adjustments for 0.9.4

* Tue Dec 04 2007 Thierry Parmentelat <thierry.parmentelat@sophia.inria.fr> 
- updated to build against kernel-devel

* Mon Apr 16 2007 Thierry Parmentelat <thierry.parmentelat@sophia.inria.fr> 
- imported 0.9.3, re-used Marcs spec file 

* Fri Dec 01 2006 Marc E. Fiuczynski <mef@cs.princeton.edu>
- Initial release
